@@ -27,6 +27,20 @@ def test_import_from_url_counters_for_part_success(tmpdir):
     assert write_result.get('total_written') == 5
 
 
+def test_exception_raised_when_unable_to_write_hosts(tmpdir):
+    """ Test that the correct exception is raised when a hosts file
+    is not writeable.
+    """
+    hosts_file = tmpdir.mkdir("etc").join("hosts")
+    hosts_file.write("127.0.0.1\tlocalhost\n")
+    hosts = Hosts(path=hosts_file.strpath)
+    os.chmod(hosts_file.strpath, 0444)
+    new_entry = HostsEntry(entry_type='ipv4', address='123.123.123.123', names=['test.example.com'])
+    hosts.add(entries=[new_entry])
+    with pytest.raises(exception.UnableToWriteHosts):
+        hosts.write()
+
+
 def test_write_will_create_path_if_missing():
     """
     Test that the hosts file declared when constructing a Hosts instance will
